#![doc = include_str!("README.md")]

#[doc = include_str!("deref.md")]
pub mod deref {}

pub mod list;

#[doc = include_str!("CHANGELOG.md")]
pub mod changelog {}

#[doc = include_str!("cargo_features.md")]
pub mod cargo_features {}
